win32com Documentation Index

#

# PythonCOM Documentation Index

The following documentation is available

A Quick Start to Client Side COM (including makepy)

A Quick Start to Server Side COM

Information on generated Python files (ie, what makepy generates)

An advanced VARIANT object which can give more control over parameter types

COM Record Support

A brief description of the win32com package structure

Python COM Implementation documentation

Misc stuff I don't know where to put anywhere else

### ActiveX Scripting

ActiveX Scripting Demos